@@ -1,6 +1,7 @@
 #ifndef DO_COMPARE_VERIFY_ONE_H
 #define DO_COMPARE_VERIFY_ONE_H
 
+#include "gettext.h"
 #include "print_error.h"
 #include "remove_source_rmdir.h"
 #include "remove_source_unlink.h"
@@ -61,7 +62,7 @@ static inline void compare_verify_two(const OPArg *oparg, const VList *file_list
 				break;
 
 			default:
-				fprintf(stderr, "ハッシュチェックオプションが不正です");
+				fprintf(stderr, _("ハッシュチェックオプションが不正です"));
 				break;
 			}
 		}
