@@ -26,112 +26,106 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd);
 *******************************************************************************/
 static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 {
-	_Bool check;
-	struct stat stat_src;
-	struct stat stat_dst;
+	_Bool is_success = false;
 
-	gboolean link_check = g_file_test(cpinfo->dst, G_FILE_TEST_IS_SYMLINK);
-	gboolean file_check = g_file_test(cpinfo->dst, G_FILE_TEST_EXISTS);
+	gboolean is_file_found = g_file_test(cpinfo->dst, G_FILE_TEST_EXISTS);
+	gboolean is_link = g_file_test(cpinfo->dst, G_FILE_TEST_IS_SYMLINK);
 
-	if((link_check == FALSE) && (file_check == FALSE))
+	if((is_file_found == FALSE) && (is_link == FALSE))
 	{
-		check = c_s(oparg, cpinfo, cpdd);
+		is_success = c_s(oparg, cpinfo, cpdd);
 	}
-	else if(link_check == TRUE)
+	else if((is_link == TRUE) && (oparg->WRITE_MODE == OVERWRITE))
 	{
-		if(oparg->WRITE_MODE == OVERWRITE)
-		{
-			errno = 0;
+		errno = 0;
 
-			if(unlink(cpinfo->dst) == -1)
+		if(unlink(cpinfo->dst) == -1)
+		{
+			UNLINK_ERR
+		}
+		else
+		{
+			is_success = c_s(oparg, cpinfo, cpdd);
+		}
+	}
+	else if(is_link == TRUE)
+	{
+		struct stat stat_src;
+		struct stat stat_dst;
+
+		errno = 0;
+
+		if(lstat(cpinfo->src, &stat_src) == -1)
+		{
+			print_error("lstat", cpinfo->src, __FILE__, __LINE__, cpdd);
+		}
+		else if(lstat(cpinfo->dst, &stat_dst) == -1)
+		{
+			if(errno == ENOENT)
 			{
-				check = false;
-				UNLINK_ERR
+				is_success = c_s(oparg, cpinfo, cpdd);
 			}
 			else
 			{
-				check = c_s(oparg, cpinfo, cpdd);
+				print_error("lstat", cpinfo->dst, __FILE__, __LINE__, cpdd);
 			}
 		}
 		else
 		{
-			errno = 0;
-
-			if(lstat(cpinfo->src, &stat_src) == -1)
+			switch(oparg->WRITE_MODE)
 			{
-				check = false;
-				print_error("lstat", cpinfo->src, __FILE__, __LINE__, cpdd);
-			}
-			else if(lstat(cpinfo->dst, &stat_dst) == -1)
-			{
-				if(errno == ENOENT)
+			case SIZE_OR_TIME:
+				if(stat_src.st_mtime != stat_dst.st_mtime)
 				{
-					check = c_s(oparg, cpinfo, cpdd);
-				}
-				else
-				{
-					check = false;
-					print_error("lstat", cpinfo->dst, __FILE__, __LINE__, cpdd);
-				}
-			}
-			else
-			{
-				switch(oparg->WRITE_MODE)
-				{
-				case SIZE_OR_TIME:
-					if(stat_src.st_mtime != stat_dst.st_mtime)
+					if(unlink(cpinfo->dst) == -1)
 					{
-						if(unlink(cpinfo->dst) == -1)
-						{
-							check = false;
-							UNLINK_ERR
-						}
-						else
-						{
-							check = c_s(oparg, cpinfo, cpdd);
-						}
+						UNLINK_ERR
 					}
 					else
 					{
-						check = false;
+						is_success = c_s(oparg, cpinfo, cpdd);
 					}
-					break;
+				}
+				break;
 
-				case NEW_TIME:
-					if(stat_src.st_mtime > stat_dst.st_mtime)
+			case NEW_TIME:
+				if(stat_src.st_mtime > stat_dst.st_mtime)
+				{
+					if(unlink(cpinfo->dst) == -1)
 					{
-						if(unlink(cpinfo->dst) == -1)
-						{
-							check = false;
-							UNLINK_ERR
-						}
-						else
-						{
-							check = c_s(oparg, cpinfo, cpdd);
-						}
+						UNLINK_ERR
 					}
 					else
 					{
-						check = false;
+						is_success = c_s(oparg, cpinfo, cpdd);
 					}
-					break;
-
-				default:
-					check = false;
-					print_error("NULL", cpinfo->src, __FILE__, __LINE__, cpdd);
-					break;
 				}
+				break;
+
+			case NO_OVERWRITE:
+				if(oparg->V == VERBOS)
+				{
+					printf(_("skip : %s\n"), cpinfo->dst);
+					fflush(stdout);
+				}
+				break;
+
+			default:
+				print_error("NULL", cpinfo->src, __FILE__, __LINE__, cpdd);
+				break;
 			}
 		}
 	}
 	else
 	{
-		printf(_("skip : %s\n"), cpinfo->dst);
-		fflush(stdout);
-		check = false;
+		if(oparg->V == VERBOS)
+		{
+			printf(_("skip : %s\n"), cpinfo->dst);
+			fflush(stdout);
+		}
 	}
 
-	if(check == true)
+	if(is_success == true)
 	{
 		cpinfo->dst_para = WRITE;
 	}
@@ -141,13 +135,12 @@ static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 *******************************************************************************/
 static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 {
+	_Bool is_success = false;
 	int readlink_len;
 	char link_buf[PATH_MAX];
-	_Bool check;
 
 	if((readlink_len = readlink(cpinfo->src, link_buf, PATH_MAX)) == -1)
 	{
-		check = false;
 		print_error("readlink", cpinfo->src, __FILE__, __LINE__, cpdd);
 	}
 	else
@@ -168,12 +161,11 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 
 		if(symlink(link_buf, cpinfo->dst) == -1)
 		{
-			check = false;
 			print_error("symlink", cpinfo->dst, __FILE__, __LINE__, cpdd);
 		}
 		else
 		{
-			check = true;
+			is_success = true;
 
 			if(cpdd->mk_link_count <= ULLONG_MAX)
 			{
@@ -199,7 +191,7 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 		}
 	}
 
-	return check;
+	return is_success;
 }
 
 #endif
