@@ -93,6 +93,8 @@ static int isrc;
 static int idst;
 static int ri;	// index number
 static int wi;	// index number
+static _Bool is_write_error;
+
 static long p_size;
 static _Bool is_verify;
 
@@ -129,6 +131,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 	idst = 0;
 	ri = 0;
 	wi = 0;
+	is_write_error = false;
 
 	if(p_size == 0)
 	{
@@ -155,9 +158,9 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 			(
 				((tmp[0] == 'e') && (tmp[1] == 'x') && (tmp[2] == 't') && (tmp[3] == '4'))
 				||
-				((tmp[0] == 'b') && (tmp[1] == 't') && (tmp[2] == 'r') && (tmp[2] == 'f') && (tmp[2] == 's'))
+				((tmp[0] == 'b') && (tmp[1] == 't') && (tmp[2] == 'r') && (tmp[3] == 'f') && (tmp[4] == 's'))
 				||
-				((tmp[0] == 'o') && (tmp[1] == 'c') && (tmp[2] == 'f') && (tmp[2] == 's') && (tmp[2] == '2'))
+				((tmp[0] == 'o') && (tmp[1] == 'c') && (tmp[2] == 'f') && (tmp[3] == 's') && (tmp[4] == '2'))
 			)
 			{
 				is_support_fallocate = true;
@@ -313,13 +316,29 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		if(fallocate(idst, FALLOC_FL_KEEP_SIZE, 0, src_size_local) == -1)
 		{
 			print_error("fallocate", cpinfo->dst, __FILE__, __LINE__, cpdd);
+
+			if(close(isrc) == -1)
+			{
+				print_error("close", cpinfo->src, __FILE__, __LINE__, cpdd);
+			}
+			else
+			{
+				is_open_src = false;
+			}
+
+			if(close(idst) == -1)
+			{
+				print_error("close", cpinfo->dst, __FILE__, __LINE__, cpdd);
+			}
+			else
+			{
+				is_open_dst = false;
+			}
 		}
 /*
-		static int itmp = -1;
-
-		if((itmp = posix_fallocate(idst, 0, src_size_local)) != 0)
+		if((int i = posix_fallocate(idst, 0, src_size_local)) != 0)
 		{
-			errno = itmp;
+			errno = i;
 			print_error("posix_fallocate", __FILE__, __LINE__, cpdd);
 		}
 */
@@ -432,8 +451,9 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		cpdd->total_write += total_write_local;
 	}
 
-	if(((is_open_src == true) &&
-		(is_open_dst == true)) &&
+	if(
+		((is_open_src == true) && (is_open_dst == true))
+		&&
 		(((0 < src_size_local) && (src_size_local <= total_write_local)) || ((src_size_local == 0) && (return_dst_ftruncate == 0)))
 	)
 	{
@@ -652,13 +672,13 @@ static inline void rw(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, _Bool is_d
 					pthread_join(t_write, NULL);
 				}
 
-				if(r == -1)
+				if((r == 0) || (is_write_error == true))
 				{
-					print_error("read", cpinfo->src, __FILE__, __LINE__, cpdd);
 					break;
 				}
-				else if(r == 0)
+				else if(r == -1)
 				{
+					print_error("read", cpinfo->src, __FILE__, __LINE__, cpdd);
 					break;
 				}
 				else
@@ -705,6 +725,7 @@ static void * write_normal(void *cpcp_tmp)
 		errno = 0;
 		if((w = write(idst, tmp, endp - tmp)) == -1)
 		{
+			is_write_error = true;
 			print_error("write", cpcp->cpinfo->dst, __FILE__, __LINE__, cpcp->cpdd);
 			break;
 		}
@@ -730,6 +751,7 @@ static void * write_dio(void *cpcp_tmp)
 
 	if((w = write(idst, buf[wi], cpcp->w_size)) == -1)
 	{
+		is_write_error = true;
 		print_error("write", cpcp->cpinfo->dst, __FILE__, __LINE__, cpcp->cpdd);
 	}
 	else
