@@ -97,7 +97,7 @@ int main(int argc, char **argv)
 	VList *file_list = rdata->file_list;
 	CPDD *cpdd = rdata->cpdd;
 
-	if((file_list != NULL) && (oparg->CHECK_MODE == AFTER) && (cpdd->mk_file_count > 0))
+	if((file_list != NULL) && (oparg->CHECK_MODE == AFTER) && ((cpdd->mk_file_count > 0) || (cpdd->mk_link_count > 0)))
 	{
 		puts(_("ハッシュ値のチェックを開始します..."));
 		fflush(stdout);
